@@ -39,7 +39,7 @@ mqcd <- function(data, data.name = NULL)
   
   p <- ncol(data) # quality characteristics
   m <- nrow(data) # number of samples or observations
-  if (class(data) == "matrix" || class(data) == "data.frame") {
+  if (inherits(data, "matrix") || inherits(data, "data.frame")) {
       names <- colnames(data)    
       data <- array(data.matrix(data),c(m,p,1))
       colnames(data) <- names        
